@@ -5,8 +5,8 @@
  */
 
 #include "dbusinterface.h"
-#include "global.h"
 #include "dolphin_generalsettings.h"
+#include "global.h"
 
 #include <KPropertiesDialog>
 #include <KWindowSystem>
@@ -14,42 +14,43 @@
 #include <QDBusConnection>
 #include <QDBusConnectionInterface>
 
-DBusInterface::DBusInterface() :
-    QObject()
+DBusInterface::DBusInterface()
+    : QObject()
 {
-    QDBusConnection::sessionBus().registerObject(QStringLiteral("/org/freedesktop/FileManager1"), this,
-            QDBusConnection::ExportScriptableContents | QDBusConnection::ExportAdaptors);
+    QDBusConnection::sessionBus().registerObject(QStringLiteral("/org/freedesktop/FileManager1"),
+                                                 this,
+                                                 QDBusConnection::ExportScriptableContents | QDBusConnection::ExportAdaptors);
     QDBusConnectionInterface *sessionInterface = QDBusConnection::sessionBus().interface();
     if (sessionInterface) {
         sessionInterface->registerService(QStringLiteral("org.freedesktop.FileManager1"), QDBusConnectionInterface::QueueService);
     }
 }
 
-void DBusInterface::ShowFolders(const QStringList& uriList, const QString& startUpId)
+void DBusInterface::ShowFolders(const QStringList &uriList, const QString &startUpId)
 {
     const QList<QUrl> urls = Dolphin::validateUris(uriList);
     if (urls.isEmpty()) {
         return;
     }
     const auto serviceName = isDaemon() ? QString() : QStringLiteral("org.kde.dolphin-%1").arg(QCoreApplication::applicationPid());
-    if(!Dolphin::attachToExistingInstance(urls, false, GeneralSettings::splitView(), serviceName, startUpId)) {
+    if (!Dolphin::attachToExistingInstance(urls, false, GeneralSettings::splitView(), serviceName, startUpId)) {
         Dolphin::openNewWindow(urls);
     }
 }
 
-void DBusInterface::ShowItems(const QStringList& uriList, const QString& startUpId)
+void DBusInterface::ShowItems(const QStringList &uriList, const QString &startUpId)
 {
     const QList<QUrl> urls = Dolphin::validateUris(uriList);
     if (urls.isEmpty()) {
         return;
     }
     const auto serviceName = isDaemon() ? QString() : QStringLiteral("org.kde.dolphin-%1").arg(QCoreApplication::applicationPid());
-    if(!Dolphin::attachToExistingInstance(urls, true, GeneralSettings::splitView(), serviceName, startUpId)) {
+    if (!Dolphin::attachToExistingInstance(urls, true, GeneralSettings::splitView(), serviceName, startUpId)) {
         Dolphin::openNewWindow(urls, nullptr, Dolphin::OpenNewWindowFlag::Select);
     };
 }
 
-void DBusInterface::ShowItemProperties(const QStringList& uriList, const QString& startUpId)
+void DBusInterface::ShowItemProperties(const QStringList &uriList, const QString &startUpId)
 {
     const QList<QUrl> urls = Dolphin::validateUris(uriList);
     if (!urls.isEmpty()) {
